@@ -3,9 +3,11 @@ Main interface for elastictranscoder service type definitions.
 
 Usage::
 
-    from mypy_boto3.elastictranscoder.type_defs import ArtworkTypeDef
+    ```python
+    from mypy_boto3_elastictranscoder.type_defs import ArtworkTypeDef
 
     data: ArtworkTypeDef = {...}
+    ```
 """
 import sys
 from typing import Dict, List
